<?php
/**
 * Theme functions and definitions
 *
 * @package Bosa News Blog 1.0.0
 */

require get_stylesheet_directory() . '/inc/customizer/customizer.php';
require get_stylesheet_directory() . '/inc/customizer/loader.php';
require get_stylesheet_directory() . '/inc/child-functions.php';

if ( ! function_exists( 'bosa_news_blog_enqueue_styles' ) ) :
	/**
	 * @since Bosa News Blog 1.0.0
	 */
	function bosa_news_blog_enqueue_styles() {
		wp_enqueue_style( 'bosa-news-blog-style-parent', get_template_directory_uri() . '/style.css',
			array(
				'bootstrap',
				'slick',
				'slicknav',
				'slick-theme',
				'fontawesome',
				'bosa-blocks',
				'bosa-google-font'
				)
		);

		wp_enqueue_style( 'bosa-news-blog-google-fonts', "https://fonts.googleapis.com/css2?family=Montserrat:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap", false );
		wp_enqueue_style( 'bosa-news-blog-google-fonts-two', "https://fonts.googleapis.com/css2?family=Open+Sans:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;1,300;1,400;1,500;1,600;1,700;1,800&display=swap", false );

	}

endif;
add_action( 'wp_enqueue_scripts', 'bosa_news_blog_enqueue_styles', 1 );

if ( ! function_exists( 'bosa_news_blog_modify_locale' ) ) :
	/**
	 * Modifies the localized array
	 *
	 * @since Bosa News Blog 1.0.0
	 * @return array
	 */
	function bosa_news_blog_modify_locale( $locale ) {

		if( isset( $locale['home_highlight_posts'] ) ){
			$locale['home_highlight_posts'] = array(
				'autoplay'      => absint( !get_theme_mod( 'disable_highlight_posts_autoplay', true ) ),
				'autoplaySpeed' => absint( get_theme_mod( 'highlight_posts_autoplay_speed', 4 ) * 1000 ),
				'slidesToShow'  => absint( get_theme_mod( 'highlight_posts_slides_show', 4 ) ),
			);
		 }
		return $locale;	
	}
	add_filter( 'bosa_localize_var', 'bosa_news_blog_modify_locale' );
endif;

function bosa_header_advertisement_banner(){
	$bannerImageID 						= get_theme_mod( 'header_advertisement_banner', '' );
	$render_header_ad_image_size 		= get_theme_mod( 'render_header_ad_image_size', 'full' );
	$header_advertisement_banner_obj 	= wp_get_attachment_image_src( $bannerImageID, $render_header_ad_image_size );
	if ( is_array(  $header_advertisement_banner_obj ) ){
		$header_advertisement_banner = $header_advertisement_banner_obj[0];
	}else{
		$header_advertisement_banner = '';
	}
	$alt = get_post_meta( $bannerImageID, '_wp_attachment_image_alt', true);
 	?>
	 	<div class="header-advertisement-banner">
	 		<a href="<?php echo esc_url( get_theme_mod( 'header_advertisement_banner_link', '' ) ); ?>" alt="<?php echo $alt; ?>" target="_blank">
	 			<img src="<?php echo esc_url( $header_advertisement_banner ); ?>">
	 		</a>
	 	</div>
	<?php
}

if( !function_exists( 'bosa_get_intermediate_image_sizes' ) ){
    /**
    * Array of image sizes.
    * 
    * @since Bosa News Blog 1.0.4
    * @return array
    */
    function bosa_get_intermediate_image_sizes(){

        $data   = array(
            'full'          => esc_html__( 'Full Size', 'bosa-news-blog' ),
            'large'         => esc_html__( 'Large Size', 'bosa-news-blog' ),
            'medium'        => esc_html__( 'Medium Size', 'bosa-news-blog' ),
            'medium_large'  => esc_html__( 'Medium Large Size', 'bosa-news-blog' ),
            'thumbnail'     => esc_html__( 'Thumbnail Size', 'bosa-news-blog' ),
            '1536x1536'     => esc_html__( '1536x1536 Size', 'bosa-news-blog' ),
            '2048x2048'     => esc_html__( '2048x2048 Size', 'bosa-news-blog' ),
            'bosa-1920-550' => esc_html__( '1920x550 Size', 'bosa-news-blog' ),
            'bosa-1370-550' => esc_html__( '1370x550 Size', 'bosa-news-blog' ),
            'bosa-590-310'  => esc_html__( '590x310 Size', 'bosa-news-blog' ),
            'bosa-420-380'  => esc_html__( '420x380 Size', 'bosa-news-blog' ),
            'bosa-420-300'  => esc_html__( '420x300 Size', 'bosa-news-blog' ),
            'bosa-420-200'  => esc_html__( '420x200 Size', 'bosa-news-blog' ),
            'bosa-290-150'  => esc_html__( '290x150 Size', 'bosa-news-blog' ),
            'bosa-80-60'    => esc_html__( '80x60 Size', 'bosa-news-blog' ),
        );
        
        return $data;

    }
}

if( !function_exists( 'bosa_news_blog_slider_layout_filter' ) ){
    /**
    * Filter of slider layout choices.
    * 
    * @since Bosa News Blog 1.0.4
    * @return array
    */
    add_filter( 'bosa_slider_layout_filter', 'bosa_news_blog_slider_layout_filter' );
    function bosa_news_blog_slider_layout_filter( $slider_layout ){
        $added_slider = array(
            'main_slider_two'    => get_stylesheet_directory_uri() . '/assets/images/slider-layout-2.png',
        );
        return array_merge( $slider_layout, $added_slider );
    }
}

if( !function_exists( 'bosa_news_blog_feature_posts_layout_filter' ) ){
    /**
    * Filter of feature posts layout choices.
    * 
    * @since Bosa News Blog 1.0.4
    * @return array
    */
    add_filter( 'bosa_feature_posts_section_layouts_filter', 'bosa_news_blog_feature_posts_layout_filter' );
    function bosa_news_blog_feature_posts_layout_filter( $feature_layout ){
        $added_feature = array(
           'feature_two'    => get_stylesheet_directory_uri() . '/assets/images/feature-post-layout-2.png',
        );
        return array_merge( $feature_layout, $added_feature );
    }
}

if( !function_exists( 'bosa_news_blog_header_layout_filter' ) ){
    /**
    * Filter of header layout choices.
    * 
    * @since Bosa News Blog 1.0.4
    * @return array
    */
    add_filter( 'bosa_header_layout_filter', 'bosa_news_blog_header_layout_filter' );
    function bosa_news_blog_header_layout_filter( $header_layout ){
        $added_header = array(
            'header_four'  => get_stylesheet_directory_uri() . '/assets/images/header-layout-4.png',
        );
        return array_merge( $header_layout, $added_header );
    }
}


add_theme_support( "title-tag" );
add_theme_support( 'automatic-feed-links' );